US Court of Appeals for the Sixth Circuit

Home | Contact Information | ECF Log-In | PACER
R. Guy Cole, Jr., Chief Judge |

| OPINIONS
| Today's Opinions Opinions Search Opinions Date Search Opinions Last 10 Days National Opinions Search
| COURTROOM AUDIO
| Recent Hearings Oral Argument Search
| ELECTRONIC CASE FILING
| COURT CALENDARS
| Oral Argument Calendar
| FORMS
| DOCKET SHEET
| COURT OF APPEALS
| Judges
| History
| CLERK'S OFFICE
| Fee Schedule Pending Cases Journals Past 7 Days
| CIRCUIT EXECUTIVE
| Judicial Complaint
| MEDIATION OFFICE
| Mediation Forms
| LIBRARY
| BANKRUPTCY APPELLATE PANEL
| BAP Forms BAP Calendar Local BAP Rules
| JUDICIAL COUNCIL
| Pattern Jury Instructions
| JUDICIAL CONFERENCE
| RULES AND PROCEDURES
| CJA TRAINING VIDEOS
| EMPLOYMENT
| TRAVEL INFORMATION
| Directions to the Court
| COURT LINKS
| SEMINARS DISCLOSURE
10-10-2014 - Friday
12-4229 David Wade v Deb Timmerman-Cooper | Play | Save
13-3777 USA v Sean Murphy | Play | Save
13-3873 United States v Clements | Play | Save
13-4397 Patricia Bolden v City of Euclid | Play | Save
13-6301 United States v Badger | Play | Save
13-6565 Dax Womack v Matt Conley | Play | Save
14-1019 UAW v General Motos LLC | Play | Save
14-1119 Syed Sami v Detroit Medical Center | Play | Save
14-1311 Lance McNeal v Gary Kott et al | Play | Save
14-3095 Tonguette v Sun Life and Health Ins et al | Play | Save
14-3118 NetJets Inc et al v IntelliJet Group LLC | Play | Save
14-3119 Kings Dodge Inc v Chrysler Group LLC | Play | Save
14-3157 Christina Smith v Erie County Sherriffs Dept | Play | Save
14-5053 John Misewicz v city of Memphis Tennessee | Play | Save
14-5155 John Ohnemus v Travis Thompson | Play | Save
14-5283 Dublin Eye Assoc v Mass Mutual Life Ins | Play | Save
14-5331 Gerald Deom et al v Walgreen Co | Play | Save

10-09-2014 - Thursday
12-3169 Sierra Club v United States Environmental Protection Agency et al | Play | Save
13-6073 United States of America v Daniel Quail | Play | Save
13-6250 EEOC v New Breed Logistics | Play | Save
13-6656 United States of America v Lee C Tevis | Play | Save
14-1151 Sylvia James v Hilliard Hampton et al | Play | Save
14-1362 Mark Judge v Landscape Forms Inc | Play | Save
14-3107 Penn LLC et al v Prosper Business Dev Corp et al | Play | Save
14-3108 Penn LLC et al v Prosper Business Dev Corp et al | Play | Save
14-3269 United States of America v Mantech Advanced Systems International et al | Play | Save

10-08-2014 - Wednesday
11-2615 Jack Parker vs Sherry Burt | Play | Save
11-6180 Gary Sutton v Wayne Carpenter | Play | Save
13-3238 Susan List v Steven Driehaus | Play | Save
13-4304 JM Smucker Co v Weston Firm PC | Play | Save
13-4386 USA v Raymond Welch II | Play | Save
13-4417 Jorge Gonzalez-Garcia v Eric Holder Jr | Play | Save
14-1094 Saeb Mokdad v Eric Holder Jr et al | Play | Save
14-3120 City of Painesville et al vs Elizabeth Goodwin et al | Play | Save

10-07-2014 - Tuesday
12-1038 Julie Pucci v Judge Mark W. Somers | Play | Save
13-2523 Buchanan v Northland Group Inc | Play | Save
13-2641 Ljuljdjuraj v State Farm Automobille Ins Co | Play | Save
13-2704 Wallace v Wayne County | Play | Save
13-3808 13-3809 Laurice Gilbert v Terry Tibbals | Play | Save
13-4356 Wheeling and Lake Erie Railway v Brotherhood of Locomotive Engineers | Play | Save
13-4379 United States of America v Deborah Kistner | Play | Save
13-5821 13-5931 USA v Kerley Whaley | Play | Save
13-5957 Steve B Smith et al v Jefferson County School Board | Play | Save
14-1027 Kalitta Air LLC v GSBD & Assoc LLC et al | Play | Save
14-1063 Boone v Heyns et al | Play | Save
14-1090 Dow Corning v Claimants Adv Comm | Play | Save
14-1392 Kishna Brown v Bradley Lewis et al | Play | Save
14-3067 Ted Doukas v George Bavelis | Play | Save
14-5123 Huff v Spaw | Play | Save
14-5192 Allen v City of Jackson | Play | Save

10-03-2014 - Friday
13-4162 Tynisa Williams et al v City of Cleveland | Play | Save
13-5790 USA v David Miner | Play | Save
14-3159 William Wells et al v Brandon Rhodes et al | Play | Save
14-5048 USA v Derrick Ball | Play | Save

10-02-2014 - Thursday
13-2269 Consolidated Rail Corp v Grand Trunk Western Railroad | Play | Save
13-2308 USA v Rufus Robinson | Play | Save
13-3950 13-3951 USA v Damien Russ | Play | Save
13-4365 USA v Theodore Harmon | Play | Save
13-6418 USA v Charles Adams | Play | Save
14-1074 Milton Spokojny v Hillard Hampton | Play | Save
14-3093 JoAnn Snyder et al v USA et al | Play | Save
14-3215 Eric White v Duke Energy Kentucky Inc | Play | Save
14-3266 Joseph Libretti Jr v Steven Woodson | Play | Save
14-5197 William Lawrence v Commonwealth of Kentucky | Play | Save
14-5219 Lisa Peterson et al v James Dean et al | Play | Save

10-01-2014 - Wednesday
09 5517 USA vs Taylor | Play | Save
11-5707 Wheeler v Simpson | Play | Save
13-4219 USA v Richard Miezin | Play | Save
13-4362 USA v State of Ohio et al | Play | Save
13-5753 USA v Christopher Clark | Play | Save
13-6508 Richard Chester Norris vs USA | Play | Save
14-1137 Stacy Fry et al v Napoleon Community Schools et al | Play | Save
14-1178 Mary Jane Gross et al v City of Dearborn Heights et al | Play | Save
14-3027 USA v David Payne | Play | Save
14-3306 Collins Inkjet Corporation v Eastman Kodak Co | Play | Save
14-5017 William Eakes III vs David Sexton | Play | Save
14-5146 Ronald Chisholm v American Cold Storage et al | Play | Save
14-5193 Applied Underwriters Captive Risk Assurance Co vs Milan Express Co | Play | Save

09-30-2014 - Tuesday
13-1260 Grumbley v Burt | Play | Save
13-2287 USA v Samuel Richardson | Play | Save
13-2513 USA v Sierra Villegas | Play | Save
13-4269 John Smith Jr v Charlotte Jenkins | Play | Save
13-6283 USA v Sean Widmer | Play | Save
13-6645 USA v Chattanooga-Hamilton Co Hosp | Play | Save
14-3002 Yoder and Frey Auctioneers v EquipmentFacts LLC | Play | Save
14-3010 Sunny Ridge Co v Keathley | Play | Save
14-3173 Barbara Moore v Christine Money et al | Play | Save
14-5047 Gary Vander Boegh v EnergySolutions Inc et al | Play | Save
14-5063 Frederick Morrow v State of Tennessee et al | Play | Save
14-5069 Lilly v City of Erlanger | Play | Save

08-26-2014 - Tuesday
13-8054 Dennis Grossman v David Wehrle | Play | Save

08-25-2014 - Monday
13-5882 Occupy Nashville et al v William Haslam et al | Play | Save

08-08-2014 - Friday
13-4111 Stew Farm Ltd v Natural Resource Conservation Service, et al | Play | Save
13-2117 2118 2119 Chrysler Group LLC v Fox Hills Motor Sales et al and Spitzer Autoworld Akron | Play | Save
13-2554 Kathleen Benison et al v George Ross et al | Play | Save
13-4390 Nadia Nathan v The Ohio State University et al | Play | Save
13-4409 William Cass et al v City of Dayton et al | Play | Save
13-4410 Glen Minges et al v Butler County Agricultural Society et al | Play | Save
13-5402 Terry Clifton v Wayne Carpenter | Play | Save
13-6394 Melvin Kindle et al v City of Jeffersontown KY et al | Play | Save
14-3037 Joseph Platt et al v Board of Commissioners et al | Play | Save

08-07-2014 - Thursday
13-2299 USA v Allebban | Play | Save
13-2331 Carey v Foley and Lardner | Play | Save
13-2451 USA v Joseph Krul | Play | Save
13-4002 Decker et al v GE Healthcare Inc et al | Play | Save
13-4052 Sister Michael Marie v American Red Cross | Play | Save
13-4101 Avis Rent A Car V City of Dayton Ohio | Play | Save
13-4348 David Antoon v Cleveland Clinic Foundation et al | Play | Save
13-5975 Green Party of TN v Tre Hargett | Play | Save
13-6446 Butler v United Healthcare | Play | Save
13-6527 Patricia Travers v Cellco Partnership dba Verizon | Play | Save
13-6548 Jeanne Wallner v JJB Hilliard WL Lyons LLC | Play | Save

| This site is managed by the United States Court of Appeals for the Sixth Circuit. External links to other Internet sites should not be construed as an endorsement of the views contained therein.